# This program generates a plot for the eigenfunctions of the finite square
# well potential with E<Vo. Below, we have a sketch of finite square well
# potential system (E<V0).
#
# __________            ___________ V0
#           |          |
# __________|__________|___________ E
#           |          |
#           |          |
# __________|__________|___________ x
#         -a/2        a/2
#
# This program uses the following libraries: matplotlib and numpy.
#
# Dr. Walter F. de Azevedo Jr.
# https://azevedolab.net/
# Porto Alegre, April 20, 2019

# Import libraries
import numpy as np
import matplotlib.pyplot as plt

# Define initial parameters
R = 4.0                # in m
epsilon =  1.25269     # for R = 4 epsilon = 1.25269
a = 1.0e-10            # a in m

# Calculate normalized A, C, and G
term_0 = np.sqrt(R**2 - epsilon**2)
term_1 = (1/term_0)*(np.cos(2*epsilon)+1)
term_2 = (1/epsilon)*(np.sin(2*epsilon) +2*epsilon)
den_C = (np.sqrt(a))*(np.sqrt(term_1 + term_2))
C = 2/den_C
A = C*(np.cos(epsilon))*(np.exp(term_0))
G = A

# Calculate k_I and k_II
k_I = (2/a)*term_0
k_II = (2/a)*epsilon

# Set up limits in m
x_min = -3e-10
x_max = 3e-10

# Define x range with linspace
x_I = np.linspace(x_min,-a/2,1000)
x_II = np.linspace(-a/2,a/2,1000)
x_III = np.linspace(a/2,x_max,1000)

# Define eigenfunction psi (solution of Schroedinger equation for finite square
# well potential (E<Vo))
psi_I = A*np.exp(k_I*x_I)
psi_II = C*np.cos(k_II*x_II)
psi_III = G*np.exp(-k_I*x_III)

# Set up x-axis limits
plt.xlim(x_min,x_max)

# Set up y-axis limits
plt.ylim(-200000.0,200000.0)

# Set up grid
plt.grid(True)

# Add labels
plt.xlabel('x ($10^{-10}m$)',fontsize=14)        # Add axis label
plt.ylabel('$\psi$',fontsize=14)                # Add axis label
plt.title('Eigenfunction for the square well potential')

# Define scientific notation for y-axis
plt.ticklabel_format(style='sci', scilimits=(-2,2), axis='y')

# Create plots
plt.plot(x_I,psi_I)
plt.plot(x_II,psi_II)
plt.plot(x_III,psi_III)

# Show plot
plt.show()

# Save plot on png file
plt.savefig("square_well_potential_psi.png")